# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class AuditContext(_message.Message):
    __slots__ = (
        "audit_log",
        "scrubbed_request",
        "scrubbed_response",
        "scrubbed_response_item_count",
        "target_resource",
    )
    AUDIT_LOG_FIELD_NUMBER: _ClassVar[int]
    SCRUBBED_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SCRUBBED_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SCRUBBED_RESPONSE_ITEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    TARGET_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    audit_log: bytes
    scrubbed_request: _struct_pb2.Struct
    scrubbed_response: _struct_pb2.Struct
    scrubbed_response_item_count: int
    target_resource: str
    def __init__(
        self,
        audit_log: _Optional[bytes] = ...,
        scrubbed_request: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        scrubbed_response: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        scrubbed_response_item_count: _Optional[int] = ...,
        target_resource: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

from google.api import annotations_pb2 as _annotations_pb2
from google.api import client_pb2 as _client_pb2
from google.rpc import status_pb2 as _status_pb2

DESCRIPTOR: _descriptor.FileDescriptor
OPERATION_INFO_FIELD_NUMBER: _ClassVar[int]
operation_info: _descriptor.FieldDescriptor

class Operation(_message.Message):
    __slots__ = ("name", "metadata", "done", "error", "response")
    NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    DONE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    name: str
    metadata: _any_pb2.Any
    done: bool
    error: _status_pb2.Status
    response: _any_pb2.Any
    def __init__(
        self,
        name: _Optional[str] = ...,
        metadata: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...,
        done: bool = ...,
        error: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...,
        response: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...,
    ) -> None: ...

class GetOperationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListOperationsRequest(_message.Message):
    __slots__ = ("name", "filter", "page_size", "page_token")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    name: str
    filter: str
    page_size: int
    page_token: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        filter: _Optional[str] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[str] = ...,
    ) -> None: ...

class ListOperationsResponse(_message.Message):
    __slots__ = ("operations", "next_page_token")
    OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    operations: _containers.RepeatedCompositeFieldContainer[Operation]
    next_page_token: str
    def __init__(
        self,
        operations: _Optional[_Iterable[_Union[Operation, _Mapping]]] = ...,
        next_page_token: _Optional[str] = ...,
    ) -> None: ...

class CancelOperationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteOperationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class WaitOperationRequest(_message.Message):
    __slots__ = ("name", "timeout")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    name: str
    timeout: _duration_pb2.Duration
    def __init__(
        self,
        name: _Optional[str] = ...,
        timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...,
    ) -> None: ...

class OperationInfo(_message.Message):
    __slots__ = ("response_type", "metadata_type")
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    METADATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    response_type: str
    metadata_type: str
    def __init__(
        self, response_type: _Optional[str] = ..., metadata_type: _Optional[str] = ...
    ) -> None: ...



# This module is provided for backwards compatibility with
# googleapis-common-protos <= 1.52.0, where this import path contained
# all of the message and gRPC definitions.

from google.longrunning.operations_pb2_grpc import *
from google.longrunning.operations_proto_pb2 import *
from google.longrunning.operations_proto_pb2 import (
    _CANCELOPERATIONREQUEST,
    _DELETEOPERATIONREQUEST,
    _GETOPERATIONREQUEST,
    _LISTOPERATIONSREQUEST,
    _LISTOPERATIONSRESPONSE,
    _OPERATION,
    _OPERATIONINFO,
    _OPERATIONS,
)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class LabelDescriptor(_message.Message):
    __slots__ = ("key", "value_type", "description")
    class ValueType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STRING: _ClassVar[LabelDescriptor.ValueType]
        BOOL: _ClassVar[LabelDescriptor.ValueType]
        INT64: _ClassVar[LabelDescriptor.ValueType]

    STRING: LabelDescriptor.ValueType
    BOOL: LabelDescriptor.ValueType
    INT64: LabelDescriptor.ValueType
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    key: str
    value_type: LabelDescriptor.ValueType
    description: str
    def __init__(
        self,
        key: _Optional[str] = ...,
        value_type: _Optional[_Union[LabelDescriptor.ValueType, str]] = ...,
        description: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

from google.api import annotations_pb2 as _annotations_pb2
from google.api import client_pb2 as _client_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ListLocationsRequest(_message.Message):
    __slots__ = ("name", "filter", "page_size", "page_token")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    name: str
    filter: str
    page_size: int
    page_token: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        filter: _Optional[str] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[str] = ...,
    ) -> None: ...

class ListLocationsResponse(_message.Message):
    __slots__ = ("locations", "next_page_token")
    LOCATIONS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    locations: _containers.RepeatedCompositeFieldContainer[Location]
    next_page_token: str
    def __init__(
        self,
        locations: _Optional[_Iterable[_Union[Location, _Mapping]]] = ...,
        next_page_token: _Optional[str] = ...,
    ) -> None: ...

class GetLocationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class Location(_message.Message):
    __slots__ = ("name", "location_id", "display_name", "labels", "metadata")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    NAME_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    location_id: str
    display_name: str
    labels: _containers.ScalarMap[str, str]
    metadata: _any_pb2.Any
    def __init__(
        self,
        name: _Optional[str] = ...,
        location_id: _Optional[str] = ...,
        display_name: _Optional[str] = ...,
        labels: _Optional[_Mapping[str, str]] = ...,
        metadata: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar

from google.protobuf import descriptor as _descriptor
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERROR_REASON_UNSPECIFIED: _ClassVar[ErrorReason]
    SERVICE_DISABLED: _ClassVar[ErrorReason]
    BILLING_DISABLED: _ClassVar[ErrorReason]
    API_KEY_INVALID: _ClassVar[ErrorReason]
    API_KEY_SERVICE_BLOCKED: _ClassVar[ErrorReason]
    API_KEY_HTTP_REFERRER_BLOCKED: _ClassVar[ErrorReason]
    API_KEY_IP_ADDRESS_BLOCKED: _ClassVar[ErrorReason]
    API_KEY_ANDROID_APP_BLOCKED: _ClassVar[ErrorReason]
    API_KEY_IOS_APP_BLOCKED: _ClassVar[ErrorReason]
    RATE_LIMIT_EXCEEDED: _ClassVar[ErrorReason]
    RESOURCE_QUOTA_EXCEEDED: _ClassVar[ErrorReason]
    LOCATION_TAX_POLICY_VIOLATED: _ClassVar[ErrorReason]
    USER_PROJECT_DENIED: _ClassVar[ErrorReason]
    CONSUMER_SUSPENDED: _ClassVar[ErrorReason]
    CONSUMER_INVALID: _ClassVar[ErrorReason]
    SECURITY_POLICY_VIOLATED: _ClassVar[ErrorReason]
    ACCESS_TOKEN_EXPIRED: _ClassVar[ErrorReason]
    ACCESS_TOKEN_SCOPE_INSUFFICIENT: _ClassVar[ErrorReason]
    ACCOUNT_STATE_INVALID: _ClassVar[ErrorReason]
    ACCESS_TOKEN_TYPE_UNSUPPORTED: _ClassVar[ErrorReason]
    CREDENTIALS_MISSING: _ClassVar[ErrorReason]
    RESOURCE_PROJECT_INVALID: _ClassVar[ErrorReason]
    SESSION_COOKIE_INVALID: _ClassVar[ErrorReason]
    USER_BLOCKED_BY_ADMIN: _ClassVar[ErrorReason]
    RESOURCE_USAGE_RESTRICTION_VIOLATED: _ClassVar[ErrorReason]
    SYSTEM_PARAMETER_UNSUPPORTED: _ClassVar[ErrorReason]
    ORG_RESTRICTION_VIOLATION: _ClassVar[ErrorReason]
    ORG_RESTRICTION_HEADER_INVALID: _ClassVar[ErrorReason]
    SERVICE_NOT_VISIBLE: _ClassVar[ErrorReason]
    GCP_SUSPENDED: _ClassVar[ErrorReason]
    LOCATION_POLICY_VIOLATED: _ClassVar[ErrorReason]
    MISSING_ORIGIN: _ClassVar[ErrorReason]
    OVERLOADED_CREDENTIALS: _ClassVar[ErrorReason]
    LOCATION_ORG_POLICY_VIOLATED: _ClassVar[ErrorReason]
    TLS_ORG_POLICY_VIOLATED: _ClassVar[ErrorReason]
    EMULATOR_QUOTA_EXCEEDED: _ClassVar[ErrorReason]
    CREDENTIAL_ANDROID_APP_INVALID: _ClassVar[ErrorReason]
    IAM_PERMISSION_DENIED: _ClassVar[ErrorReason]
    JWT_TOKEN_INVALID: _ClassVar[ErrorReason]
    CREDENTIAL_TYPE_UNSUPPORTED: _ClassVar[ErrorReason]
    ACCOUNT_TYPE_UNSUPPORTED: _ClassVar[ErrorReason]
    ENDPOINT_USAGE_RESTRICTION_VIOLATED: _ClassVar[ErrorReason]
    TLS_CIPHER_RESTRICTION_VIOLATED: _ClassVar[ErrorReason]
    MCP_SERVER_DISABLED: _ClassVar[ErrorReason]

ERROR_REASON_UNSPECIFIED: ErrorReason
SERVICE_DISABLED: ErrorReason
BILLING_DISABLED: ErrorReason
API_KEY_INVALID: ErrorReason
API_KEY_SERVICE_BLOCKED: ErrorReason
API_KEY_HTTP_REFERRER_BLOCKED: ErrorReason
API_KEY_IP_ADDRESS_BLOCKED: ErrorReason
API_KEY_ANDROID_APP_BLOCKED: ErrorReason
API_KEY_IOS_APP_BLOCKED: ErrorReason
RATE_LIMIT_EXCEEDED: ErrorReason
RESOURCE_QUOTA_EXCEEDED: ErrorReason
LOCATION_TAX_POLICY_VIOLATED: ErrorReason
USER_PROJECT_DENIED: ErrorReason
CONSUMER_SUSPENDED: ErrorReason
CONSUMER_INVALID: ErrorReason
SECURITY_POLICY_VIOLATED: ErrorReason
ACCESS_TOKEN_EXPIRED: ErrorReason
ACCESS_TOKEN_SCOPE_INSUFFICIENT: ErrorReason
ACCOUNT_STATE_INVALID: ErrorReason
ACCESS_TOKEN_TYPE_UNSUPPORTED: ErrorReason
CREDENTIALS_MISSING: ErrorReason
RESOURCE_PROJECT_INVALID: ErrorReason
SESSION_COOKIE_INVALID: ErrorReason
USER_BLOCKED_BY_ADMIN: ErrorReason
RESOURCE_USAGE_RESTRICTION_VIOLATED: ErrorReason
SYSTEM_PARAMETER_UNSUPPORTED: ErrorReason
ORG_RESTRICTION_VIOLATION: ErrorReason
ORG_RESTRICTION_HEADER_INVALID: ErrorReason
SERVICE_NOT_VISIBLE: ErrorReason
GCP_SUSPENDED: ErrorReason
LOCATION_POLICY_VIOLATED: ErrorReason
MISSING_ORIGIN: ErrorReason
OVERLOADED_CREDENTIALS: ErrorReason
LOCATION_ORG_POLICY_VIOLATED: ErrorReason
TLS_ORG_POLICY_VIOLATED: ErrorReason
EMULATOR_QUOTA_EXCEEDED: ErrorReason
CREDENTIAL_ANDROID_APP_INVALID: ErrorReason
IAM_PERMISSION_DENIED: ErrorReason
JWT_TOKEN_INVALID: ErrorReason
CREDENTIAL_TYPE_UNSUPPORTED: ErrorReason
ACCOUNT_TYPE_UNSUPPORTED: ErrorReason
ENDPOINT_USAGE_RESTRICTION_VIOLATED: ErrorReason
TLS_CIPHER_RESTRICTION_VIOLATED: ErrorReason
MCP_SERVER_DISABLED: ErrorReason



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Color(_message.Message):
    __slots__ = ("red", "green", "blue", "alpha")
    RED_FIELD_NUMBER: _ClassVar[int]
    GREEN_FIELD_NUMBER: _ClassVar[int]
    BLUE_FIELD_NUMBER: _ClassVar[int]
    ALPHA_FIELD_NUMBER: _ClassVar[int]
    red: float
    green: float
    blue: float
    alpha: _wrappers_pb2.FloatValue
    def __init__(
        self,
        red: _Optional[float] = ...,
        green: _Optional[float] = ...,
        blue: _Optional[float] = ...,
        alpha: _Optional[_Union[_wrappers_pb2.FloatValue, _Mapping]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message

DESCRIPTOR: _descriptor.FileDescriptor

class PhoneNumber(_message.Message):
    __slots__ = ("e164_number", "short_code", "extension")
    class ShortCode(_message.Message):
        __slots__ = ("region_code", "number")
        REGION_CODE_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        region_code: str
        number: str
        def __init__(
            self, region_code: _Optional[str] = ..., number: _Optional[str] = ...
        ) -> None: ...

    E164_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SHORT_CODE_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    e164_number: str
    short_code: PhoneNumber.ShortCode
    extension: str
    def __init__(
        self,
        e164_number: _Optional[str] = ...,
        short_code: _Optional[_Union[PhoneNumber.ShortCode, _Mapping]] = ...,
        extension: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Distribution(_message.Message):
    __slots__ = (
        "count",
        "mean",
        "sum_of_squared_deviation",
        "range",
        "bucket_options",
        "bucket_counts",
        "exemplars",
    )
    class Range(_message.Message):
        __slots__ = ("min", "max")
        MIN_FIELD_NUMBER: _ClassVar[int]
        MAX_FIELD_NUMBER: _ClassVar[int]
        min: float
        max: float
        def __init__(
            self, min: _Optional[float] = ..., max: _Optional[float] = ...
        ) -> None: ...

    class BucketOptions(_message.Message):
        __slots__ = ("linear_buckets", "exponential_buckets", "explicit_buckets")
        class Linear(_message.Message):
            __slots__ = ("num_finite_buckets", "width", "offset")
            NUM_FINITE_BUCKETS_FIELD_NUMBER: _ClassVar[int]
            WIDTH_FIELD_NUMBER: _ClassVar[int]
            OFFSET_FIELD_NUMBER: _ClassVar[int]
            num_finite_buckets: int
            width: float
            offset: float
            def __init__(
                self,
                num_finite_buckets: _Optional[int] = ...,
                width: _Optional[float] = ...,
                offset: _Optional[float] = ...,
            ) -> None: ...

        class Exponential(_message.Message):
            __slots__ = ("num_finite_buckets", "growth_factor", "scale")
            NUM_FINITE_BUCKETS_FIELD_NUMBER: _ClassVar[int]
            GROWTH_FACTOR_FIELD_NUMBER: _ClassVar[int]
            SCALE_FIELD_NUMBER: _ClassVar[int]
            num_finite_buckets: int
            growth_factor: float
            scale: float
            def __init__(
                self,
                num_finite_buckets: _Optional[int] = ...,
                growth_factor: _Optional[float] = ...,
                scale: _Optional[float] = ...,
            ) -> None: ...

        class Explicit(_message.Message):
            __slots__ = ("bounds",)
            BOUNDS_FIELD_NUMBER: _ClassVar[int]
            bounds: _containers.RepeatedScalarFieldContainer[float]
            def __init__(self, bounds: _Optional[_Iterable[float]] = ...) -> None: ...

        LINEAR_BUCKETS_FIELD_NUMBER: _ClassVar[int]
        EXPONENTIAL_BUCKETS_FIELD_NUMBER: _ClassVar[int]
        EXPLICIT_BUCKETS_FIELD_NUMBER: _ClassVar[int]
        linear_buckets: Distribution.BucketOptions.Linear
        exponential_buckets: Distribution.BucketOptions.Exponential
        explicit_buckets: Distribution.BucketOptions.Explicit
        def __init__(
            self,
            linear_buckets: _Optional[
                _Union[Distribution.BucketOptions.Linear, _Mapping]
            ] = ...,
            exponential_buckets: _Optional[
                _Union[Distribution.BucketOptions.Exponential, _Mapping]
            ] = ...,
            explicit_buckets: _Optional[
                _Union[Distribution.BucketOptions.Explicit, _Mapping]
            ] = ...,
        ) -> None: ...

    class Exemplar(_message.Message):
        __slots__ = ("value", "timestamp", "attachments")
        VALUE_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
        value: float
        timestamp: _timestamp_pb2.Timestamp
        attachments: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
        def __init__(
            self,
            value: _Optional[float] = ...,
            timestamp: _Optional[
                _Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]
            ] = ...,
            attachments: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...,
        ) -> None: ...

    COUNT_FIELD_NUMBER: _ClassVar[int]
    MEAN_FIELD_NUMBER: _ClassVar[int]
    SUM_OF_SQUARED_DEVIATION_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    BUCKET_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    BUCKET_COUNTS_FIELD_NUMBER: _ClassVar[int]
    EXEMPLARS_FIELD_NUMBER: _ClassVar[int]
    count: int
    mean: float
    sum_of_squared_deviation: float
    range: Distribution.Range
    bucket_options: Distribution.BucketOptions
    bucket_counts: _containers.RepeatedScalarFieldContainer[int]
    exemplars: _containers.RepeatedCompositeFieldContainer[Distribution.Exemplar]
    def __init__(
        self,
        count: _Optional[int] = ...,
        mean: _Optional[float] = ...,
        sum_of_squared_deviation: _Optional[float] = ...,
        range: _Optional[_Union[Distribution.Range, _Mapping]] = ...,
        bucket_options: _Optional[_Union[Distribution.BucketOptions, _Mapping]] = ...,
        bucket_counts: _Optional[_Iterable[int]] = ...,
        exemplars: _Optional[_Iterable[_Union[Distribution.Exemplar, _Mapping]]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/cloud/common_resources.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/cloud/common_resources.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n#google/cloud/common_resources.proto\x12\x0cgoogle.cloud\x1a\x19google/api/resource.protoB\xf9\x02\xea\x41\x41\n+cloudresourcemanager.googleapis.com/Project\x12\x12projects/{project}\xea\x41P\n0cloudresourcemanager.googleapis.com/Organization\x12\x1corganizations/{organization}\xea\x41>\n*cloudresourcemanager.googleapis.com/Folder\x12\x10\x66olders/{folder}\xea\x41O\n*cloudbilling.googleapis.com/BillingAccount\x12!billingAccounts/{billing_account}\xea\x41L\n!locations.googleapis.com/Location\x12'projects/{project}/locations/{location}b\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.cloud.common_resources_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\352AA\n+cloudresourcemanager.googleapis.com/Project\022\022projects/{project}\352AP\n0cloudresourcemanager.googleapis.com/Organization\022\034organizations/{organization}\352A>\n*cloudresourcemanager.googleapis.com/Folder\022\020folders/{folder}\352AO\n*cloudbilling.googleapis.com/BillingAccount\022!billingAccounts/{billing_account}\352AL\n!locations.googleapis.com/Location\022'projects/{project}/locations/{location}"
# @@protoc_insertion_point(module_scope)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Quota(_message.Message):
    __slots__ = ("limits", "metric_rules")
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    METRIC_RULES_FIELD_NUMBER: _ClassVar[int]
    limits: _containers.RepeatedCompositeFieldContainer[QuotaLimit]
    metric_rules: _containers.RepeatedCompositeFieldContainer[MetricRule]
    def __init__(
        self,
        limits: _Optional[_Iterable[_Union[QuotaLimit, _Mapping]]] = ...,
        metric_rules: _Optional[_Iterable[_Union[MetricRule, _Mapping]]] = ...,
    ) -> None: ...

class MetricRule(_message.Message):
    __slots__ = ("selector", "metric_costs")
    class MetricCostsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[int] = ...
        ) -> None: ...

    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    METRIC_COSTS_FIELD_NUMBER: _ClassVar[int]
    selector: str
    metric_costs: _containers.ScalarMap[str, int]
    def __init__(
        self,
        selector: _Optional[str] = ...,
        metric_costs: _Optional[_Mapping[str, int]] = ...,
    ) -> None: ...

class QuotaLimit(_message.Message):
    __slots__ = (
        "name",
        "description",
        "default_limit",
        "max_limit",
        "free_tier",
        "duration",
        "metric",
        "unit",
        "values",
        "display_name",
    )
    class ValuesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[int] = ...
        ) -> None: ...

    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MAX_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FREE_TIER_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    default_limit: int
    max_limit: int
    free_tier: int
    duration: str
    metric: str
    unit: str
    values: _containers.ScalarMap[str, int]
    display_name: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        default_limit: _Optional[int] = ...,
        max_limit: _Optional[int] = ...,
        free_tier: _Optional[int] = ...,
        duration: _Optional[str] = ...,
        metric: _Optional[str] = ...,
        unit: _Optional[str] = ...,
        values: _Optional[_Mapping[str, int]] = ...,
        display_name: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Logging(_message.Message):
    __slots__ = ("producer_destinations", "consumer_destinations")
    class LoggingDestination(_message.Message):
        __slots__ = ("monitored_resource", "logs")
        MONITORED_RESOURCE_FIELD_NUMBER: _ClassVar[int]
        LOGS_FIELD_NUMBER: _ClassVar[int]
        monitored_resource: str
        logs: _containers.RepeatedScalarFieldContainer[str]
        def __init__(
            self,
            monitored_resource: _Optional[str] = ...,
            logs: _Optional[_Iterable[str]] = ...,
        ) -> None: ...

    PRODUCER_DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    producer_destinations: _containers.RepeatedCompositeFieldContainer[
        Logging.LoggingDestination
    ]
    consumer_destinations: _containers.RepeatedCompositeFieldContainer[
        Logging.LoggingDestination
    ]
    def __init__(
        self,
        producer_destinations: _Optional[
            _Iterable[_Union[Logging.LoggingDestination, _Mapping]]
        ] = ...,
        consumer_destinations: _Optional[
            _Iterable[_Union[Logging.LoggingDestination, _Mapping]]
        ] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class GapicMetadata(_message.Message):
    __slots__ = (
        "schema",
        "comment",
        "language",
        "proto_package",
        "library_package",
        "services",
    )

    class ServicesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: GapicMetadata.ServiceForTransport
        def __init__(
            self,
            key: _Optional[str] = ...,
            value: _Optional[_Union[GapicMetadata.ServiceForTransport, _Mapping]] = ...,
        ) -> None: ...

    class ServiceForTransport(_message.Message):
        __slots__ = ("clients", "api_version")

        class ClientsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: GapicMetadata.ServiceAsClient
            def __init__(
                self,
                key: _Optional[str] = ...,
                value: _Optional[_Union[GapicMetadata.ServiceAsClient, _Mapping]] = ...,
            ) -> None: ...

        CLIENTS_FIELD_NUMBER: _ClassVar[int]
        API_VERSION_FIELD_NUMBER: _ClassVar[int]
        clients: _containers.MessageMap[str, GapicMetadata.ServiceAsClient]
        api_version: str
        def __init__(
            self,
            clients: _Optional[_Mapping[str, GapicMetadata.ServiceAsClient]] = ...,
            api_version: _Optional[str] = ...,
        ) -> None: ...

    class ServiceAsClient(_message.Message):
        __slots__ = ("library_client", "rpcs")

        class RpcsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: GapicMetadata.MethodList
            def __init__(
                self,
                key: _Optional[str] = ...,
                value: _Optional[_Union[GapicMetadata.MethodList, _Mapping]] = ...,
            ) -> None: ...

        LIBRARY_CLIENT_FIELD_NUMBER: _ClassVar[int]
        RPCS_FIELD_NUMBER: _ClassVar[int]
        library_client: str
        rpcs: _containers.MessageMap[str, GapicMetadata.MethodList]
        def __init__(
            self,
            library_client: _Optional[str] = ...,
            rpcs: _Optional[_Mapping[str, GapicMetadata.MethodList]] = ...,
        ) -> None: ...

    class MethodList(_message.Message):
        __slots__ = ("methods",)
        METHODS_FIELD_NUMBER: _ClassVar[int]
        methods: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, methods: _Optional[_Iterable[str]] = ...) -> None: ...

    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    PROTO_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    schema: str
    comment: str
    language: str
    proto_package: str
    library_package: str
    services: _containers.MessageMap[str, GapicMetadata.ServiceForTransport]
    def __init__(
        self,
        schema: _Optional[str] = ...,
        comment: _Optional[str] = ...,
        language: _Optional[str] = ...,
        proto_package: _Optional[str] = ...,
        library_package: _Optional[str] = ...,
        services: _Optional[_Mapping[str, GapicMetadata.ServiceForTransport]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/visibility.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/api/visibility.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bgoogle/api/visibility.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto"7\n\nVisibility\x12)\n\x05rules\x18\x01 \x03(\x0b\x32\x1a.google.api.VisibilityRule"7\n\x0eVisibilityRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0brestriction\x18\x02 \x01(\t:T\n\x0f\x65num_visibility\x12\x1c.google.protobuf.EnumOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x10value_visibility\x12!.google.protobuf.EnumValueOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x10\x66ield_visibility\x12\x1d.google.protobuf.FieldOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x12message_visibility\x12\x1f.google.protobuf.MessageOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:X\n\x11method_visibility\x12\x1e.google.protobuf.MethodOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x0e\x61pi_visibility\x12\x1f.google.protobuf.ServiceOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRuleBk\n\x0e\x63om.google.apiB\x0fVisibilityProtoP\x01Z?google.golang.org/genproto/googleapis/api/visibility;visibility\xa2\x02\x04GAPIb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.api.visibility_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.google.apiB\017VisibilityProtoP\001Z?google.golang.org/genproto/googleapis/api/visibility;visibility\242\002\004GAPI"
    _globals["_VISIBILITY"]._serialized_start = 77
    _globals["_VISIBILITY"]._serialized_end = 132
    _globals["_VISIBILITYRULE"]._serialized_start = 134
    _globals["_VISIBILITYRULE"]._serialized_end = 189
# @@protoc_insertion_point(module_scope)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class OperationResponseMapping(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNDEFINED: _ClassVar[OperationResponseMapping]
    NAME: _ClassVar[OperationResponseMapping]
    STATUS: _ClassVar[OperationResponseMapping]
    ERROR_CODE: _ClassVar[OperationResponseMapping]
    ERROR_MESSAGE: _ClassVar[OperationResponseMapping]

UNDEFINED: OperationResponseMapping
NAME: OperationResponseMapping
STATUS: OperationResponseMapping
ERROR_CODE: OperationResponseMapping
ERROR_MESSAGE: OperationResponseMapping
OPERATION_FIELD_FIELD_NUMBER: _ClassVar[int]
operation_field: _descriptor.FieldDescriptor
OPERATION_REQUEST_FIELD_FIELD_NUMBER: _ClassVar[int]
operation_request_field: _descriptor.FieldDescriptor
OPERATION_RESPONSE_FIELD_FIELD_NUMBER: _ClassVar[int]
operation_response_field: _descriptor.FieldDescriptor
OPERATION_SERVICE_FIELD_NUMBER: _ClassVar[int]
operation_service: _descriptor.FieldDescriptor
OPERATION_POLLING_METHOD_FIELD_NUMBER: _ClassVar[int]
operation_polling_method: _descriptor.FieldDescriptor



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Context(_message.Message):
    __slots__ = ("rules",)
    RULES_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[ContextRule]
    def __init__(
        self, rules: _Optional[_Iterable[_Union[ContextRule, _Mapping]]] = ...
    ) -> None: ...

class ContextRule(_message.Message):
    __slots__ = (
        "selector",
        "requested",
        "provided",
        "allowed_request_extensions",
        "allowed_response_extensions",
    )
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    REQUESTED_FIELD_NUMBER: _ClassVar[int]
    PROVIDED_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_REQUEST_EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_RESPONSE_EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    selector: str
    requested: _containers.RepeatedScalarFieldContainer[str]
    provided: _containers.RepeatedScalarFieldContainer[str]
    allowed_request_extensions: _containers.RepeatedScalarFieldContainer[str]
    allowed_response_extensions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        selector: _Optional[str] = ...,
        requested: _Optional[_Iterable[str]] = ...,
        provided: _Optional[_Iterable[str]] = ...,
        allowed_request_extensions: _Optional[_Iterable[str]] = ...,
        allowed_response_extensions: _Optional[_Iterable[str]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectProperties(_message.Message):
    __slots__ = ("properties",)
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    properties: _containers.RepeatedCompositeFieldContainer[Property]
    def __init__(
        self, properties: _Optional[_Iterable[_Union[Property, _Mapping]]] = ...
    ) -> None: ...

class Property(_message.Message):
    __slots__ = ("name", "type", "description")
    class PropertyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSPECIFIED: _ClassVar[Property.PropertyType]
        INT64: _ClassVar[Property.PropertyType]
        BOOL: _ClassVar[Property.PropertyType]
        STRING: _ClassVar[Property.PropertyType]
        DOUBLE: _ClassVar[Property.PropertyType]

    UNSPECIFIED: Property.PropertyType
    INT64: Property.PropertyType
    BOOL: Property.PropertyType
    STRING: Property.PropertyType
    DOUBLE: Property.PropertyType
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: Property.PropertyType
    description: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        type: _Optional[_Union[Property.PropertyType, str]] = ...,
        description: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class SourceInfo(_message.Message):
    __slots__ = ("source_files",)
    SOURCE_FILES_FIELD_NUMBER: _ClassVar[int]
    source_files: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(
        self, source_files: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

from google.api import label_pb2 as _label_pb2
from google.api import launch_stage_pb2 as _launch_stage_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class MetricDescriptor(_message.Message):
    __slots__ = (
        "name",
        "type",
        "labels",
        "metric_kind",
        "value_type",
        "unit",
        "description",
        "display_name",
        "metadata",
        "launch_stage",
        "monitored_resource_types",
    )
    class MetricKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        METRIC_KIND_UNSPECIFIED: _ClassVar[MetricDescriptor.MetricKind]
        GAUGE: _ClassVar[MetricDescriptor.MetricKind]
        DELTA: _ClassVar[MetricDescriptor.MetricKind]
        CUMULATIVE: _ClassVar[MetricDescriptor.MetricKind]

    METRIC_KIND_UNSPECIFIED: MetricDescriptor.MetricKind
    GAUGE: MetricDescriptor.MetricKind
    DELTA: MetricDescriptor.MetricKind
    CUMULATIVE: MetricDescriptor.MetricKind
    class ValueType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VALUE_TYPE_UNSPECIFIED: _ClassVar[MetricDescriptor.ValueType]
        BOOL: _ClassVar[MetricDescriptor.ValueType]
        INT64: _ClassVar[MetricDescriptor.ValueType]
        DOUBLE: _ClassVar[MetricDescriptor.ValueType]
        STRING: _ClassVar[MetricDescriptor.ValueType]
        DISTRIBUTION: _ClassVar[MetricDescriptor.ValueType]
        MONEY: _ClassVar[MetricDescriptor.ValueType]

    VALUE_TYPE_UNSPECIFIED: MetricDescriptor.ValueType
    BOOL: MetricDescriptor.ValueType
    INT64: MetricDescriptor.ValueType
    DOUBLE: MetricDescriptor.ValueType
    STRING: MetricDescriptor.ValueType
    DISTRIBUTION: MetricDescriptor.ValueType
    MONEY: MetricDescriptor.ValueType
    class MetricDescriptorMetadata(_message.Message):
        __slots__ = (
            "launch_stage",
            "sample_period",
            "ingest_delay",
            "time_series_resource_hierarchy_level",
        )
        class TimeSeriesResourceHierarchyLevel(
            int, metaclass=_enum_type_wrapper.EnumTypeWrapper
        ):
            __slots__ = ()
            TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_UNSPECIFIED: _ClassVar[
                MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
            ]
            PROJECT: _ClassVar[
                MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
            ]
            ORGANIZATION: _ClassVar[
                MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
            ]
            FOLDER: _ClassVar[
                MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
            ]

        TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_UNSPECIFIED: (
            MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
        )
        PROJECT: (
            MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
        )
        ORGANIZATION: (
            MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
        )
        FOLDER: (
            MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
        )
        LAUNCH_STAGE_FIELD_NUMBER: _ClassVar[int]
        SAMPLE_PERIOD_FIELD_NUMBER: _ClassVar[int]
        INGEST_DELAY_FIELD_NUMBER: _ClassVar[int]
        TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_FIELD_NUMBER: _ClassVar[int]
        launch_stage: _launch_stage_pb2.LaunchStage
        sample_period: _duration_pb2.Duration
        ingest_delay: _duration_pb2.Duration
        time_series_resource_hierarchy_level: _containers.RepeatedScalarFieldContainer[
            MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel
        ]
        def __init__(
            self,
            launch_stage: _Optional[_Union[_launch_stage_pb2.LaunchStage, str]] = ...,
            sample_period: _Optional[
                _Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]
            ] = ...,
            ingest_delay: _Optional[
                _Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]
            ] = ...,
            time_series_resource_hierarchy_level: _Optional[
                _Iterable[
                    _Union[
                        MetricDescriptor.MetricDescriptorMetadata.TimeSeriesResourceHierarchyLevel,
                        str,
                    ]
                ]
            ] = ...,
        ) -> None: ...

    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    METRIC_KIND_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LAUNCH_STAGE_FIELD_NUMBER: _ClassVar[int]
    MONITORED_RESOURCE_TYPES_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    labels: _containers.RepeatedCompositeFieldContainer[_label_pb2.LabelDescriptor]
    metric_kind: MetricDescriptor.MetricKind
    value_type: MetricDescriptor.ValueType
    unit: str
    description: str
    display_name: str
    metadata: MetricDescriptor.MetricDescriptorMetadata
    launch_stage: _launch_stage_pb2.LaunchStage
    monitored_resource_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        name: _Optional[str] = ...,
        type: _Optional[str] = ...,
        labels: _Optional[
            _Iterable[_Union[_label_pb2.LabelDescriptor, _Mapping]]
        ] = ...,
        metric_kind: _Optional[_Union[MetricDescriptor.MetricKind, str]] = ...,
        value_type: _Optional[_Union[MetricDescriptor.ValueType, str]] = ...,
        unit: _Optional[str] = ...,
        description: _Optional[str] = ...,
        display_name: _Optional[str] = ...,
        metadata: _Optional[
            _Union[MetricDescriptor.MetricDescriptorMetadata, _Mapping]
        ] = ...,
        launch_stage: _Optional[_Union[_launch_stage_pb2.LaunchStage, str]] = ...,
        monitored_resource_types: _Optional[_Iterable[str]] = ...,
    ) -> None: ...

class Metric(_message.Message):
    __slots__ = ("type", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    type: str
    labels: _containers.ScalarMap[str, str]
    def __init__(
        self, type: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...
    ) -> None: ...



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/code.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/rpc/code.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x15google/rpc/code.proto\x12\ngoogle.rpc*\xb7\x02\n\x04\x43ode\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x42X\n\x0e\x63om.google.rpcB\tCodeProtoP\x01Z3google.golang.org/genproto/googleapis/rpc/code;code\xa2\x02\x03RPCb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "google.rpc.code_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.google.rpcB\tCodeProtoP\001Z3google.golang.org/genproto/googleapis/rpc/code;code\242\002\003RPC"
    _globals["_CODE"]._serialized_start = 38
    _globals["_CODE"]._serialized_end = 349
# @@protoc_insertion_point(module_scope)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import api_pb2 as _api_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import type_pb2 as _type_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers

from google.api import auth_pb2 as _auth_pb2
from google.api import backend_pb2 as _backend_pb2
from google.api import billing_pb2 as _billing_pb2
from google.api import client_pb2 as _client_pb2
from google.api import context_pb2 as _context_pb2
from google.api import control_pb2 as _control_pb2
from google.api import documentation_pb2 as _documentation_pb2
from google.api import endpoint_pb2 as _endpoint_pb2
from google.api import http_pb2 as _http_pb2
from google.api import log_pb2 as _log_pb2
from google.api import logging_pb2 as _logging_pb2
from google.api import metric_pb2 as _metric_pb2
from google.api import monitored_resource_pb2 as _monitored_resource_pb2
from google.api import monitoring_pb2 as _monitoring_pb2
from google.api import quota_pb2 as _quota_pb2
from google.api import source_info_pb2 as _source_info_pb2
from google.api import system_parameter_pb2 as _system_parameter_pb2
from google.api import usage_pb2 as _usage_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Service(_message.Message):
    __slots__ = (
        "name",
        "title",
        "producer_project_id",
        "id",
        "apis",
        "types",
        "enums",
        "documentation",
        "backend",
        "http",
        "quota",
        "authentication",
        "context",
        "usage",
        "endpoints",
        "control",
        "logs",
        "metrics",
        "monitored_resources",
        "billing",
        "logging",
        "monitoring",
        "system_parameters",
        "source_info",
        "publishing",
        "config_version",
    )
    NAME_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    PRODUCER_PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    APIS_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    ENUMS_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTATION_FIELD_NUMBER: _ClassVar[int]
    BACKEND_FIELD_NUMBER: _ClassVar[int]
    HTTP_FIELD_NUMBER: _ClassVar[int]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    CONTROL_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    MONITORED_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    BILLING_FIELD_NUMBER: _ClassVar[int]
    LOGGING_FIELD_NUMBER: _ClassVar[int]
    MONITORING_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_INFO_FIELD_NUMBER: _ClassVar[int]
    PUBLISHING_FIELD_NUMBER: _ClassVar[int]
    CONFIG_VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    title: str
    producer_project_id: str
    id: str
    apis: _containers.RepeatedCompositeFieldContainer[_api_pb2.Api]
    types: _containers.RepeatedCompositeFieldContainer[_type_pb2.Type]
    enums: _containers.RepeatedCompositeFieldContainer[_type_pb2.Enum]
    documentation: _documentation_pb2.Documentation
    backend: _backend_pb2.Backend
    http: _http_pb2.Http
    quota: _quota_pb2.Quota
    authentication: _auth_pb2.Authentication
    context: _context_pb2.Context
    usage: _usage_pb2.Usage
    endpoints: _containers.RepeatedCompositeFieldContainer[_endpoint_pb2.Endpoint]
    control: _control_pb2.Control
    logs: _containers.RepeatedCompositeFieldContainer[_log_pb2.LogDescriptor]
    metrics: _containers.RepeatedCompositeFieldContainer[_metric_pb2.MetricDescriptor]
    monitored_resources: _containers.RepeatedCompositeFieldContainer[
        _monitored_resource_pb2.MonitoredResourceDescriptor
    ]
    billing: _billing_pb2.Billing
    logging: _logging_pb2.Logging
    monitoring: _monitoring_pb2.Monitoring
    system_parameters: _system_parameter_pb2.SystemParameters
    source_info: _source_info_pb2.SourceInfo
    publishing: _client_pb2.Publishing
    config_version: _wrappers_pb2.UInt32Value
    def __init__(
        self,
        name: _Optional[str] = ...,
        title: _Optional[str] = ...,
        producer_project_id: _Optional[str] = ...,
        id: _Optional[str] = ...,
        apis: _Optional[_Iterable[_Union[_api_pb2.Api, _Mapping]]] = ...,
        types: _Optional[_Iterable[_Union[_type_pb2.Type, _Mapping]]] = ...,
        enums: _Optional[_Iterable[_Union[_type_pb2.Enum, _Mapping]]] = ...,
        documentation: _Optional[
            _Union[_documentation_pb2.Documentation, _Mapping]
        ] = ...,
        backend: _Optional[_Union[_backend_pb2.Backend, _Mapping]] = ...,
        http: _Optional[_Union[_http_pb2.Http, _Mapping]] = ...,
        quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...,
        authentication: _Optional[_Union[_auth_pb2.Authentication, _Mapping]] = ...,
        context: _Optional[_Union[_context_pb2.Context, _Mapping]] = ...,
        usage: _Optional[_Union[_usage_pb2.Usage, _Mapping]] = ...,
        endpoints: _Optional[_Iterable[_Union[_endpoint_pb2.Endpoint, _Mapping]]] = ...,
        control: _Optional[_Union[_control_pb2.Control, _Mapping]] = ...,
        logs: _Optional[_Iterable[_Union[_log_pb2.LogDescriptor, _Mapping]]] = ...,
        metrics: _Optional[
            _Iterable[_Union[_metric_pb2.MetricDescriptor, _Mapping]]
        ] = ...,
        monitored_resources: _Optional[
            _Iterable[
                _Union[_monitored_resource_pb2.MonitoredResourceDescriptor, _Mapping]
            ]
        ] = ...,
        billing: _Optional[_Union[_billing_pb2.Billing, _Mapping]] = ...,
        logging: _Optional[_Union[_logging_pb2.Logging, _Mapping]] = ...,
        monitoring: _Optional[_Union[_monitoring_pb2.Monitoring, _Mapping]] = ...,
        system_parameters: _Optional[
            _Union[_system_parameter_pb2.SystemParameters, _Mapping]
        ] = ...,
        source_info: _Optional[_Union[_source_info_pb2.SourceInfo, _Mapping]] = ...,
        publishing: _Optional[_Union[_client_pb2.Publishing, _Mapping]] = ...,
        config_version: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar

from google.protobuf import descriptor as _descriptor
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class LogSeverity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEFAULT: _ClassVar[LogSeverity]
    DEBUG: _ClassVar[LogSeverity]
    INFO: _ClassVar[LogSeverity]
    NOTICE: _ClassVar[LogSeverity]
    WARNING: _ClassVar[LogSeverity]
    ERROR: _ClassVar[LogSeverity]
    CRITICAL: _ClassVar[LogSeverity]
    ALERT: _ClassVar[LogSeverity]
    EMERGENCY: _ClassVar[LogSeverity]

DEFAULT: LogSeverity
DEBUG: LogSeverity
INFO: LogSeverity
NOTICE: LogSeverity
WARNING: LogSeverity
ERROR: LogSeverity
CRITICAL: LogSeverity
ALERT: LogSeverity
EMERGENCY: LogSeverity



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/dayofweek.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/type/dayofweek.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1bgoogle/type/dayofweek.proto\x12\x0bgoogle.type*\x84\x01\n\tDayOfWeek\x12\x1b\n\x17\x44\x41Y_OF_WEEK_UNSPECIFIED\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\x42i\n\x0f\x63om.google.typeB\x0e\x44\x61yOfWeekProtoP\x01Z>google.golang.org/genproto/googleapis/type/dayofweek;dayofweek\xa2\x02\x03GTPb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.type.dayofweek_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\017com.google.typeB\016DayOfWeekProtoP\001Z>google.golang.org/genproto/googleapis/type/dayofweek;dayofweek\242\002\003GTP"
    _globals["_DAYOFWEEK"]._serialized_start = 45
    _globals["_DAYOFWEEK"]._serialized_end = 177
# @@protoc_insertion_point(module_scope)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Documentation(_message.Message):
    __slots__ = (
        "summary",
        "pages",
        "rules",
        "documentation_root_url",
        "service_root_url",
        "overview",
    )
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    PAGES_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTATION_ROOT_URL_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ROOT_URL_FIELD_NUMBER: _ClassVar[int]
    OVERVIEW_FIELD_NUMBER: _ClassVar[int]
    summary: str
    pages: _containers.RepeatedCompositeFieldContainer[Page]
    rules: _containers.RepeatedCompositeFieldContainer[DocumentationRule]
    documentation_root_url: str
    service_root_url: str
    overview: str
    def __init__(
        self,
        summary: _Optional[str] = ...,
        pages: _Optional[_Iterable[_Union[Page, _Mapping]]] = ...,
        rules: _Optional[_Iterable[_Union[DocumentationRule, _Mapping]]] = ...,
        documentation_root_url: _Optional[str] = ...,
        service_root_url: _Optional[str] = ...,
        overview: _Optional[str] = ...,
    ) -> None: ...

class DocumentationRule(_message.Message):
    __slots__ = ("selector", "description", "deprecation_description")
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DEPRECATION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    selector: str
    description: str
    deprecation_description: str
    def __init__(
        self,
        selector: _Optional[str] = ...,
        description: _Optional[str] = ...,
        deprecation_description: _Optional[str] = ...,
    ) -> None: ...

class Page(_message.Message):
    __slots__ = ("name", "content", "subpages")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    SUBPAGES_FIELD_NUMBER: _ClassVar[int]
    name: str
    content: str
    subpages: _containers.RepeatedCompositeFieldContainer[Page]
    def __init__(
        self,
        name: _Optional[str] = ...,
        content: _Optional[str] = ...,
        subpages: _Optional[_Iterable[_Union[Page, _Mapping]]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import ClassVar as _ClassVar

from google.protobuf import descriptor as _descriptor
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper

DESCRIPTOR: _descriptor.FileDescriptor

class Code(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OK: _ClassVar[Code]
    CANCELLED: _ClassVar[Code]
    UNKNOWN: _ClassVar[Code]
    INVALID_ARGUMENT: _ClassVar[Code]
    DEADLINE_EXCEEDED: _ClassVar[Code]
    NOT_FOUND: _ClassVar[Code]
    ALREADY_EXISTS: _ClassVar[Code]
    PERMISSION_DENIED: _ClassVar[Code]
    UNAUTHENTICATED: _ClassVar[Code]
    RESOURCE_EXHAUSTED: _ClassVar[Code]
    FAILED_PRECONDITION: _ClassVar[Code]
    ABORTED: _ClassVar[Code]
    OUT_OF_RANGE: _ClassVar[Code]
    UNIMPLEMENTED: _ClassVar[Code]
    INTERNAL: _ClassVar[Code]
    UNAVAILABLE: _ClassVar[Code]
    DATA_LOSS: _ClassVar[Code]

OK: Code
CANCELLED: Code
UNKNOWN: Code
INVALID_ARGUMENT: Code
DEADLINE_EXCEEDED: Code
NOT_FOUND: Code
ALREADY_EXISTS: Code
PERMISSION_DENIED: Code
UNAUTHENTICATED: Code
RESOURCE_EXHAUSTED: Code
FAILED_PRECONDITION: Code
ABORTED: Code
OUT_OF_RANGE: Code
UNIMPLEMENTED: Code
INTERNAL: Code
UNAVAILABLE: Code
DATA_LOSS: Code



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/error_details.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/rpc/error_details.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1egoogle/rpc/error_details.proto\x12\ngoogle.rpc\x1a\x1egoogle/protobuf/duration.proto"\x93\x01\n\tErrorInfo\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x35\n\x08metadata\x18\x03 \x03(\x0b\x32#.google.rpc.ErrorInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01";\n\tRetryInfo\x12.\n\x0bretry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration"2\n\tDebugInfo\x12\x15\n\rstack_entries\x18\x01 \x03(\t\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t"\x8f\x03\n\x0cQuotaFailure\x12\x36\n\nviolations\x18\x01 \x03(\x0b\x32".google.rpc.QuotaFailure.Violation\x1a\xc6\x02\n\tViolation\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x61pi_service\x18\x03 \x01(\t\x12\x14\n\x0cquota_metric\x18\x04 \x01(\t\x12\x10\n\x08quota_id\x18\x05 \x01(\t\x12Q\n\x10quota_dimensions\x18\x06 \x03(\x0b\x32\x37.google.rpc.QuotaFailure.Violation.QuotaDimensionsEntry\x12\x13\n\x0bquota_value\x18\x07 \x01(\x03\x12\x1f\n\x12\x66uture_quota_value\x18\x08 \x01(\x03H\x00\x88\x01\x01\x1a\x36\n\x14QuotaDimensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x15\n\x13_future_quota_value"\x95\x01\n\x13PreconditionFailure\x12=\n\nviolations\x18\x01 \x03(\x0b\x32).google.rpc.PreconditionFailure.Violation\x1a?\n\tViolation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"\xcc\x01\n\nBadRequest\x12?\n\x10\x66ield_violations\x18\x01 \x03(\x0b\x32%.google.rpc.BadRequest.FieldViolation\x1a}\n\x0e\x46ieldViolation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x37\n\x11localized_message\x18\x04 \x01(\x0b\x32\x1c.google.rpc.LocalizedMessage"7\n\x0bRequestInfo\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_data\x18\x02 \x01(\t"`\n\x0cResourceInfo\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t"V\n\x04Help\x12$\n\x05links\x18\x01 \x03(\x0b\x32\x15.google.rpc.Help.Link\x1a(\n\x04Link\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t"3\n\x10LocalizedMessage\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\tBl\n\x0e\x63om.google.rpcB\x11\x45rrorDetailsProtoP\x01Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\xa2\x02\x03RPCb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.rpc.error_details_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.google.rpcB\021ErrorDetailsProtoP\001Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\242\002\003RPC"
    _globals["_ERRORINFO_METADATAENTRY"]._loaded_options = None
    _globals["_ERRORINFO_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY"]._loaded_options = None
    _globals[
        "_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY"
    ]._serialized_options = b"8\001"
    _globals["_ERRORINFO"]._serialized_start = 79
    _globals["_ERRORINFO"]._serialized_end = 226
    _globals["_ERRORINFO_METADATAENTRY"]._serialized_start = 179
    _globals["_ERRORINFO_METADATAENTRY"]._serialized_end = 226
    _globals["_RETRYINFO"]._serialized_start = 228
    _globals["_RETRYINFO"]._serialized_end = 287
    _globals["_DEBUGINFO"]._serialized_start = 289
    _globals["_DEBUGINFO"]._serialized_end = 339
    _globals["_QUOTAFAILURE"]._serialized_start = 342
    _globals["_QUOTAFAILURE"]._serialized_end = 741
    _globals["_QUOTAFAILURE_VIOLATION"]._serialized_start = 415
    _globals["_QUOTAFAILURE_VIOLATION"]._serialized_end = 741
    _globals["_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY"]._serialized_start = 664
    _globals["_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY"]._serialized_end = 718
    _globals["_PRECONDITIONFAILURE"]._serialized_start = 744
    _globals["_PRECONDITIONFAILURE"]._serialized_end = 893
    _globals["_PRECONDITIONFAILURE_VIOLATION"]._serialized_start = 830
    _globals["_PRECONDITIONFAILURE_VIOLATION"]._serialized_end = 893
    _globals["_BADREQUEST"]._serialized_start = 896
    _globals["_BADREQUEST"]._serialized_end = 1100
    _globals["_BADREQUEST_FIELDVIOLATION"]._serialized_start = 975
    _globals["_BADREQUEST_FIELDVIOLATION"]._serialized_end = 1100
    _globals["_REQUESTINFO"]._serialized_start = 1102
    _globals["_REQUESTINFO"]._serialized_end = 1157
    _globals["_RESOURCEINFO"]._serialized_start = 1159
    _globals["_RESOURCEINFO"]._serialized_end = 1255
    _globals["_HELP"]._serialized_start = 1257
    _globals["_HELP"]._serialized_end = 1343
    _globals["_HELP_LINK"]._serialized_start = 1303
    _globals["_HELP_LINK"]._serialized_end = 1343
    _globals["_LOCALIZEDMESSAGE"]._serialized_start = 1345
    _globals["_LOCALIZEDMESSAGE"]._serialized_end = 1396
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/resource.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 33, 5, "", "google/api/resource.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19google/api/resource.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto"\xee\x02\n\x12ResourceDescriptor\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x03(\t\x12\x12\n\nname_field\x18\x03 \x01(\t\x12\x37\n\x07history\x18\x04 \x01(\x0e\x32&.google.api.ResourceDescriptor.History\x12\x0e\n\x06plural\x18\x05 \x01(\t\x12\x10\n\x08singular\x18\x06 \x01(\t\x12\x33\n\x05style\x18\n \x03(\x0e\x32$.google.api.ResourceDescriptor.Style"[\n\x07History\x12\x17\n\x13HISTORY_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORIGINALLY_SINGLE_PATTERN\x10\x01\x12\x18\n\x14\x46UTURE_MULTI_PATTERN\x10\x02"8\n\x05Style\x12\x15\n\x11STYLE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45\x43LARATIVE_FRIENDLY\x10\x01"5\n\x11ResourceReference\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x12\n\nchild_type\x18\x02 \x01(\t:Y\n\x12resource_reference\x12\x1d.google.protobuf.FieldOptions\x18\x9f\x08 \x01(\x0b\x32\x1d.google.api.ResourceReference:Z\n\x13resource_definition\x12\x1c.google.protobuf.FileOptions\x18\x9d\x08 \x03(\x0b\x32\x1e.google.api.ResourceDescriptor:R\n\x08resource\x12\x1f.google.protobuf.MessageOptions\x18\x9d\x08 \x01(\x0b\x32\x1e.google.api.ResourceDescriptorBk\n\x0e\x63om.google.apiB\rResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPIb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "google.api.resource_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.google.apiB\rResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\004GAPI"
    _globals["_RESOURCEDESCRIPTOR"]._serialized_start = 76
    _globals["_RESOURCEDESCRIPTOR"]._serialized_end = 442
    _globals["_RESOURCEDESCRIPTOR_HISTORY"]._serialized_start = 293
    _globals["_RESOURCEDESCRIPTOR_HISTORY"]._serialized_end = 384
    _globals["_RESOURCEDESCRIPTOR_STYLE"]._serialized_start = 386
    _globals["_RESOURCEDESCRIPTOR_STYLE"]._serialized_end = 442
    _globals["_RESOURCEREFERENCE"]._serialized_start = 444
    _globals["_RESOURCEREFERENCE"]._serialized_end = 497
# @@protoc_insertion_point(module_scope)



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Usage(_message.Message):
    __slots__ = ("requirements", "rules", "producer_notification_channel")
    REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    PRODUCER_NOTIFICATION_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    requirements: _containers.RepeatedScalarFieldContainer[str]
    rules: _containers.RepeatedCompositeFieldContainer[UsageRule]
    producer_notification_channel: str
    def __init__(
        self,
        requirements: _Optional[_Iterable[str]] = ...,
        rules: _Optional[_Iterable[_Union[UsageRule, _Mapping]]] = ...,
        producer_notification_channel: _Optional[str] = ...,
    ) -> None: ...

class UsageRule(_message.Message):
    __slots__ = ("selector", "allow_unregistered_calls", "skip_service_control")
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UNREGISTERED_CALLS_FIELD_NUMBER: _ClassVar[int]
    SKIP_SERVICE_CONTROL_FIELD_NUMBER: _ClassVar[int]
    selector: str
    allow_unregistered_calls: bool
    skip_service_control: bool
    def __init__(
        self,
        selector: _Optional[str] = ...,
        allow_unregistered_calls: _Optional[bool] = ...,
        skip_service_control: _Optional[bool] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorInfo(_message.Message):
    __slots__ = ("reason", "domain", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    REASON_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    reason: str
    domain: str
    metadata: _containers.ScalarMap[str, str]
    def __init__(
        self,
        reason: _Optional[str] = ...,
        domain: _Optional[str] = ...,
        metadata: _Optional[_Mapping[str, str]] = ...,
    ) -> None: ...

class RetryInfo(_message.Message):
    __slots__ = ("retry_delay",)
    RETRY_DELAY_FIELD_NUMBER: _ClassVar[int]
    retry_delay: _duration_pb2.Duration
    def __init__(
        self,
        retry_delay: _Optional[
            _Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]
        ] = ...,
    ) -> None: ...

class DebugInfo(_message.Message):
    __slots__ = ("stack_entries", "detail")
    STACK_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    stack_entries: _containers.RepeatedScalarFieldContainer[str]
    detail: str
    def __init__(
        self,
        stack_entries: _Optional[_Iterable[str]] = ...,
        detail: _Optional[str] = ...,
    ) -> None: ...

class QuotaFailure(_message.Message):
    __slots__ = ("violations",)
    class Violation(_message.Message):
        __slots__ = (
            "subject",
            "description",
            "api_service",
            "quota_metric",
            "quota_id",
            "quota_dimensions",
            "quota_value",
            "future_quota_value",
        )
        class QuotaDimensionsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(
                self, key: _Optional[str] = ..., value: _Optional[str] = ...
            ) -> None: ...

        SUBJECT_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        API_SERVICE_FIELD_NUMBER: _ClassVar[int]
        QUOTA_METRIC_FIELD_NUMBER: _ClassVar[int]
        QUOTA_ID_FIELD_NUMBER: _ClassVar[int]
        QUOTA_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
        QUOTA_VALUE_FIELD_NUMBER: _ClassVar[int]
        FUTURE_QUOTA_VALUE_FIELD_NUMBER: _ClassVar[int]
        subject: str
        description: str
        api_service: str
        quota_metric: str
        quota_id: str
        quota_dimensions: _containers.ScalarMap[str, str]
        quota_value: int
        future_quota_value: int
        def __init__(
            self,
            subject: _Optional[str] = ...,
            description: _Optional[str] = ...,
            api_service: _Optional[str] = ...,
            quota_metric: _Optional[str] = ...,
            quota_id: _Optional[str] = ...,
            quota_dimensions: _Optional[_Mapping[str, str]] = ...,
            quota_value: _Optional[int] = ...,
            future_quota_value: _Optional[int] = ...,
        ) -> None: ...

    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[QuotaFailure.Violation]
    def __init__(
        self,
        violations: _Optional[
            _Iterable[_Union[QuotaFailure.Violation, _Mapping]]
        ] = ...,
    ) -> None: ...

class PreconditionFailure(_message.Message):
    __slots__ = ("violations",)
    class Violation(_message.Message):
        __slots__ = ("type", "subject", "description")
        TYPE_FIELD_NUMBER: _ClassVar[int]
        SUBJECT_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        type: str
        subject: str
        description: str
        def __init__(
            self,
            type: _Optional[str] = ...,
            subject: _Optional[str] = ...,
            description: _Optional[str] = ...,
        ) -> None: ...

    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[
        PreconditionFailure.Violation
    ]
    def __init__(
        self,
        violations: _Optional[
            _Iterable[_Union[PreconditionFailure.Violation, _Mapping]]
        ] = ...,
    ) -> None: ...

class BadRequest(_message.Message):
    __slots__ = ("field_violations",)
    class FieldViolation(_message.Message):
        __slots__ = ("field", "description", "reason", "localized_message")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        REASON_FIELD_NUMBER: _ClassVar[int]
        LOCALIZED_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        field: str
        description: str
        reason: str
        localized_message: LocalizedMessage
        def __init__(
            self,
            field: _Optional[str] = ...,
            description: _Optional[str] = ...,
            reason: _Optional[str] = ...,
            localized_message: _Optional[_Union[LocalizedMessage, _Mapping]] = ...,
        ) -> None: ...

    FIELD_VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    field_violations: _containers.RepeatedCompositeFieldContainer[
        BadRequest.FieldViolation
    ]
    def __init__(
        self,
        field_violations: _Optional[
            _Iterable[_Union[BadRequest.FieldViolation, _Mapping]]
        ] = ...,
    ) -> None: ...

class RequestInfo(_message.Message):
    __slots__ = ("request_id", "serving_data")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SERVING_DATA_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    serving_data: str
    def __init__(
        self, request_id: _Optional[str] = ..., serving_data: _Optional[str] = ...
    ) -> None: ...

class ResourceInfo(_message.Message):
    __slots__ = ("resource_type", "resource_name", "owner", "description")
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    resource_type: str
    resource_name: str
    owner: str
    description: str
    def __init__(
        self,
        resource_type: _Optional[str] = ...,
        resource_name: _Optional[str] = ...,
        owner: _Optional[str] = ...,
        description: _Optional[str] = ...,
    ) -> None: ...

class Help(_message.Message):
    __slots__ = ("links",)
    class Link(_message.Message):
        __slots__ = ("description", "url")
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        URL_FIELD_NUMBER: _ClassVar[int]
        description: str
        url: str
        def __init__(
            self, description: _Optional[str] = ..., url: _Optional[str] = ...
        ) -> None: ...

    LINKS_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[Help.Link]
    def __init__(
        self, links: _Optional[_Iterable[_Union[Help.Link, _Mapping]]] = ...
    ) -> None: ...

class LocalizedMessage(_message.Message):
    __slots__ = ("locale", "message")
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    message: str
    def __init__(
        self, locale: _Optional[str] = ..., message: _Optional[str] = ...
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class PostalAddress(_message.Message):
    __slots__ = (
        "revision",
        "region_code",
        "language_code",
        "postal_code",
        "sorting_code",
        "administrative_area",
        "locality",
        "sublocality",
        "address_lines",
        "recipients",
        "organization",
    )
    REVISION_FIELD_NUMBER: _ClassVar[int]
    REGION_CODE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    POSTAL_CODE_FIELD_NUMBER: _ClassVar[int]
    SORTING_CODE_FIELD_NUMBER: _ClassVar[int]
    ADMINISTRATIVE_AREA_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_FIELD_NUMBER: _ClassVar[int]
    SUBLOCALITY_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_LINES_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    revision: int
    region_code: str
    language_code: str
    postal_code: str
    sorting_code: str
    administrative_area: str
    locality: str
    sublocality: str
    address_lines: _containers.RepeatedScalarFieldContainer[str]
    recipients: _containers.RepeatedScalarFieldContainer[str]
    organization: str
    def __init__(
        self,
        revision: _Optional[int] = ...,
        region_code: _Optional[str] = ...,
        language_code: _Optional[str] = ...,
        postal_code: _Optional[str] = ...,
        sorting_code: _Optional[str] = ...,
        administrative_area: _Optional[str] = ...,
        locality: _Optional[str] = ...,
        sublocality: _Optional[str] = ...,
        address_lines: _Optional[_Iterable[str]] = ...,
        recipients: _Optional[_Iterable[str]] = ...,
        organization: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers

from google.api import label_pb2 as _label_pb2
from google.api import launch_stage_pb2 as _launch_stage_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class MonitoredResourceDescriptor(_message.Message):
    __slots__ = (
        "name",
        "type",
        "display_name",
        "description",
        "labels",
        "launch_stage",
    )
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LAUNCH_STAGE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    display_name: str
    description: str
    labels: _containers.RepeatedCompositeFieldContainer[_label_pb2.LabelDescriptor]
    launch_stage: _launch_stage_pb2.LaunchStage
    def __init__(
        self,
        name: _Optional[str] = ...,
        type: _Optional[str] = ...,
        display_name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        labels: _Optional[
            _Iterable[_Union[_label_pb2.LabelDescriptor, _Mapping]]
        ] = ...,
        launch_stage: _Optional[_Union[_launch_stage_pb2.LaunchStage, str]] = ...,
    ) -> None: ...

class MonitoredResource(_message.Message):
    __slots__ = ("type", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    type: str
    labels: _containers.ScalarMap[str, str]
    def __init__(
        self, type: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...
    ) -> None: ...

class MonitoredResourceMetadata(_message.Message):
    __slots__ = ("system_labels", "user_labels")
    class UserLabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[str] = ...
        ) -> None: ...

    SYSTEM_LABELS_FIELD_NUMBER: _ClassVar[int]
    USER_LABELS_FIELD_NUMBER: _ClassVar[int]
    system_labels: _struct_pb2.Struct
    user_labels: _containers.ScalarMap[str, str]
    def __init__(
        self,
        system_labels: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        user_labels: _Optional[_Mapping[str, str]] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import message as _message

DESCRIPTOR: _descriptor.FileDescriptor

class HttpRequest(_message.Message):
    __slots__ = (
        "request_method",
        "request_url",
        "request_size",
        "status",
        "response_size",
        "user_agent",
        "remote_ip",
        "server_ip",
        "referer",
        "latency",
        "cache_lookup",
        "cache_hit",
        "cache_validated_with_origin_server",
        "cache_fill_bytes",
        "protocol",
    )
    REQUEST_METHOD_FIELD_NUMBER: _ClassVar[int]
    REQUEST_URL_FIELD_NUMBER: _ClassVar[int]
    REQUEST_SIZE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_SIZE_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    REMOTE_IP_FIELD_NUMBER: _ClassVar[int]
    SERVER_IP_FIELD_NUMBER: _ClassVar[int]
    REFERER_FIELD_NUMBER: _ClassVar[int]
    LATENCY_FIELD_NUMBER: _ClassVar[int]
    CACHE_LOOKUP_FIELD_NUMBER: _ClassVar[int]
    CACHE_HIT_FIELD_NUMBER: _ClassVar[int]
    CACHE_VALIDATED_WITH_ORIGIN_SERVER_FIELD_NUMBER: _ClassVar[int]
    CACHE_FILL_BYTES_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    request_method: str
    request_url: str
    request_size: int
    status: int
    response_size: int
    user_agent: str
    remote_ip: str
    server_ip: str
    referer: str
    latency: _duration_pb2.Duration
    cache_lookup: bool
    cache_hit: bool
    cache_validated_with_origin_server: bool
    cache_fill_bytes: int
    protocol: str
    def __init__(
        self,
        request_method: _Optional[str] = ...,
        request_url: _Optional[str] = ...,
        request_size: _Optional[int] = ...,
        status: _Optional[int] = ...,
        response_size: _Optional[int] = ...,
        user_agent: _Optional[str] = ...,
        remote_ip: _Optional[str] = ...,
        server_ip: _Optional[str] = ...,
        referer: _Optional[str] = ...,
        latency: _Optional[
            _Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]
        ] = ...,
        cache_lookup: _Optional[bool] = ...,
        cache_hit: _Optional[bool] = ...,
        cache_validated_with_origin_server: _Optional[bool] = ...,
        cache_fill_bytes: _Optional[int] = ...,
        protocol: _Optional[str] = ...,
    ) -> None: ...



# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from collections.abc import Iterable as _Iterable
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers

DESCRIPTOR: _descriptor.FileDescriptor

class Http(_message.Message):
    __slots__ = ("rules", "fully_decode_reserved_expansion")
    RULES_FIELD_NUMBER: _ClassVar[int]
    FULLY_DECODE_RESERVED_EXPANSION_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[HttpRule]
    fully_decode_reserved_expansion: bool
    def __init__(
        self,
        rules: _Optional[_Iterable[_Union[HttpRule, _Mapping]]] = ...,
        fully_decode_reserved_expansion: _Optional[bool] = ...,
    ) -> None: ...

class HttpRule(_message.Message):
    __slots__ = (
        "selector",
        "get",
        "put",
        "post",
        "delete",
        "patch",
        "custom",
        "body",
        "response_body",
        "additional_bindings",
    )
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    GET_FIELD_NUMBER: _ClassVar[int]
    PUT_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    selector: str
    get: str
    put: str
    post: str
    delete: str
    patch: str
    custom: CustomHttpPattern
    body: str
    response_body: str
    additional_bindings: _containers.RepeatedCompositeFieldContainer[HttpRule]
    def __init__(
        self,
        selector: _Optional[str] = ...,
        get: _Optional[str] = ...,
        put: _Optional[str] = ...,
        post: _Optional[str] = ...,
        delete: _Optional[str] = ...,
        patch: _Optional[str] = ...,
        custom: _Optional[_Union[CustomHttpPattern, _Mapping]] = ...,
        body: _Optional[str] = ...,
        response_body: _Optional[str] = ...,
        additional_bindings: _Optional[_Iterable[_Union[HttpRule, _Mapping]]] = ...,
    ) -> None: ...

class CustomHttpPattern(_message.Message):
    __slots__ = ("kind", "path")
    KIND_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    kind: str
    path: str
    def __init__(
        self, kind: _Optional[str] = ..., path: _Optional[str] = ...
    ) -> None: ...
